@@ -8,14 +8,16 @@ from datacrunch.ssh_keys.ssh_keys import SSHKeysService
 from datacrunch.startup_scripts.startup_scripts import StartupScriptsService
 from datacrunch.volume_types.volume_types import VolumeTypesService
 from datacrunch.volumes.volumes import VolumesService
+from datacrunch.containers.containers import ContainersService
 from datacrunch.constants import Constants
+from datacrunch.locations.locations import LocationsService
 from datacrunch.__version__ import VERSION
 
 
 class DataCrunchClient:
     """Client for interacting with DataCrunch's public API"""
 
-    def __init__(self, client_id: str, client_secret: str, base_url: str = "https://api.datacrunch.io/v1") -> None:
+    def __init__(self, client_id: str, client_secret: str, base_url: str = "https://api.datacrunch.io/v1", inference_key: str = None) -> None:
         """The DataCrunch client
 
         :param client_id: client id
@@ -24,8 +26,15 @@ class DataCrunchClient:
         :type client_secret: str
         :param base_url: base url for all the endpoints, optional, defaults to "https://api.datacrunch.io/v1"
         :type base_url: str, optional
+        :param inference_key: inference key, optional
+        :type inference_key: str, optional
         """
 
+        # Validate that client_id and client_secret are not empty
+        if not client_id or not client_secret:
+            raise ValueError(
+                "client_id and client_secret must be provided")
+
         # Constants
         self.constants: Constants = Constants(base_url, VERSION)
         """Constants"""
@@ -62,3 +71,11 @@ class DataCrunchClient:
 
         self.volumes: VolumesService = VolumesService(self._http_client)
         """Volume service. Create, attach, detach, get, rename, delete volumes"""
+
+        self.locations: LocationsService = LocationsService(
+            self._http_client)
+        """Locations service. Get locations"""
+
+        self.containers: ContainersService = ContainersService(
+            self._http_client, inference_key)
+        """Containers service. Deploy, manage, and monitor container deployments"""
