@@ -3,7 +3,7 @@ import responses  # https://github.com/getsentry/responses
 
 from datacrunch.exceptions import APIException
 from datacrunch.instances.instances import InstancesService, Instance
-from datacrunch.constants import Actions, ErrorCodes
+from datacrunch.constants import Actions, ErrorCodes, Locations
 
 INVALID_REQUEST = ErrorCodes.INVALID_REQUEST
 INVALID_REQUEST_MESSAGE = 'Your existence is invalid'
@@ -13,12 +13,12 @@ SSH_KEY_ID = '12345dc1-a5d2-4972-ae4e-d429115d055b'
 OS_VOLUME_ID = '46fc0247-8f65-4d8a-ad73-852a8b3dc1d3'
 
 INSTANCE_TYPE = "1V100.6V"
-INSTANCE_IMAGE = "fastai"
+INSTANCE_IMAGE = "ubuntu-24.04-cuda-12.8-open-docker"
 INSTANCE_HOSTNAME = "I'll be your host for today"
 INSTANCE_DESCRIPTION = "hope you enjoy your GPU"
 INSTANCE_STATUS = 'running'
 INSTANCE_PRICE_PER_HOUR = 0.60
-INSTANCE_LOCATION = 'FIN1'
+INSTANCE_LOCATION = Locations.FIN_01
 INSTANCE_IP = '1.2.3.4'
 INSTANCE_CREATED_AT = "whatchalookingatboy?"
 INSTANCE_OS_VOLUME = {"name": "os volume", "size": 50}
@@ -63,6 +63,7 @@ PAYLOAD = [
 PAYLOAD_SPOT = PAYLOAD
 PAYLOAD_SPOT[0]["is_spot"] = True
 
+
 class TestInstancesService:
     @pytest.fixture
     def instances_service(self, http_client):
@@ -397,7 +398,8 @@ class TestInstancesService:
         )
 
         # act
-        result = instances_service.action(id_list=[INSTANCE_ID], action=Actions.SHUTDOWN)
+        result = instances_service.action(
+            id_list=[INSTANCE_ID], action=Actions.SHUTDOWN)
 
         # assert
         assert result is None
@@ -415,7 +417,8 @@ class TestInstancesService:
 
         # act
         with pytest.raises(APIException) as excinfo:
-            instances_service.action(id_list=[INSTANCE_ID], action="fluxturcate")
+            instances_service.action(
+                id_list=[INSTANCE_ID], action="fluxturcate")
 
         # assert
         assert excinfo.value.code == INVALID_REQUEST
@@ -424,7 +427,8 @@ class TestInstancesService:
 
     def test_is_available_successful(self, instances_service):
         # arrange - add response mock
-        url = instances_service._http_client._base_url + '/instance-availability/' + INSTANCE_TYPE
+        url = instances_service._http_client._base_url + \
+            '/instance-availability/' + INSTANCE_TYPE + "?isSpot=false"
         responses.add(
             responses.GET,
             url,
@@ -441,7 +445,8 @@ class TestInstancesService:
 
     def test_is_spot_available_successful(self, instances_service):
         # arrange - add response mock
-        url = instances_service._http_client._base_url + '/instance-availability/' + INSTANCE_TYPE + '?isSpot=true'
+        url = instances_service._http_client._base_url + \
+            '/instance-availability/' + INSTANCE_TYPE + '?isSpot=true'
         responses.add(
             responses.GET,
             url,
@@ -450,7 +455,8 @@ class TestInstancesService:
         )
 
         # act
-        is_available = instances_service.is_available(INSTANCE_TYPE, is_spot=True)
+        is_available = instances_service.is_available(
+            INSTANCE_TYPE, is_spot=True)
 
         # assert
         assert is_available is True
@@ -458,7 +464,8 @@ class TestInstancesService:
 
     def test_is_available_failed(self, instances_service):
         # arrange - add response mock
-        url = instances_service._http_client._base_url + '/instance-availability/x'
+        url = instances_service._http_client._base_url + \
+            '/instance-availability/x' + "?isSpot=false"
         responses.add(
             responses.GET,
             url,
@@ -473,4 +480,4 @@ class TestInstancesService:
         # assert
         assert excinfo.value.code == INVALID_REQUEST
         assert excinfo.value.message == INVALID_REQUEST_MESSAGE
-        assert responses.assert_call_count(url, 1) is True
\ No newline at end of file
+        assert responses.assert_call_count(url, 1) is True
